==> gnuradio-docs-3.10.12.0-7-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/group__peak__detectors__blk.js <==
var group__peak__detectors__blk =
[
    [ "gr::analog::dpll_bb", "classgr_1_1analog_1_1dpll__bb.html", [
      [ "sptr", "classgr_1_1analog_1_1dpll__bb.html#a4cd3aab598fe459a633a410d9dc5f2bd", null ],
      [ "decision_threshold", "classgr_1_1analog_1_1dpll__bb.html#a53e1c566e50ef63f4d5e0b8fb84a484e", null ],
      [ "freq", "classgr_1_1analog_1_1dpll__bb.html#abedeabbf4b0049752c0b3be852e95a3c", null ],
      [ "gain", "classgr_1_1analog_1_1dpll__bb.html#a1da82673c6f625cd7cf0f444852cd0a4", null ],
      [ "make", "classgr_1_1analog_1_1dpll__bb.html#a980b6ceddb6b3209359bb3aa1f36976e", null ],
      [ "phase", "classgr_1_1analog_1_1dpll__bb.html#aab727744be92198f2d4711e5f0f19678", null ],
      [ "set_decision_threshold", "classgr_1_1analog_1_1dpll__bb.html#a546eabcaa34f18be69565c641601ec3d", null ],
      [ "set_gain", "classgr_1_1analog_1_1dpll__bb.html#a02c324b9cf55007fc47fdb2da3084ee5", null ]
    ] ],
    [ "gr::blocks::burst_tagger", "classgr_1_1blocks_1_1burst__tagger.html", [
      [ "sptr", "classgr_1_1blocks_1_1burst__tagger.html#a1273ae5546bff6510eddff6f95efbce7", null ],
      [ "make", "classgr_1_1blocks_1_1burst__tagger.html#a4908a2d6815e3d9a12b2b7212161dc08", null ],
      [ "set_false_tag", "classgr_1_1blocks_1_1burst__tagger.html#aeab711b3fa1a9cc7faac0f511dd5b63d", null ],
      [ "set_true_tag", "classgr_1_1blocks_1_1burst__tagger.html#ab6b752543e52c9fca97343a1cac39d7c", null ]
    ] ],
    [ "gr::blocks::peak_detector< T >", "classgr_1_1blocks_1_1peak__detector.html", [
      [ "sptr", "classgr_1_1blocks_1_1peak__detector.html#a004eabbc41caff4d11bc4e48b8fc8fd7", null ],
      [ "alpha", "classgr_1_1blocks_1_1peak__detector.html#a84b44dfcbb5afe0f66b9b3f6beeccebc", null ],
      [ "look_ahead", "classgr_1_1blocks_1_1peak__detector.html#ab23b61ab46bc6d7f120e7a6b152ab56d", null ],
      [ "make", "classgr_1_1blocks_1_1peak__detector.html#aab118d4bb43e6884f87fc7f99b18c26c", null ],
      [ "set_alpha", "classgr_1_1blocks_1_1peak__detector.html#aae8136f9c7c7990aaa1217e1b21973be", null ],
      [ "set_look_ahead", "classgr_1_1blocks_1_1peak__detector.html#a6b0179950aef78cfccf0db5e4fb7c8f1", null ],
      [ "set_threshold_factor_fall", "classgr_1_1blocks_1_1peak__detector.html#a78f1f05b1345d3fd248f7112b0b9dfae", null ],
      [ "set_threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector.html#ace2098fbf2075d6c0c0cc2190a071cf2", null ],
      [ "threshold_factor_fall", "classgr_1_1blocks_1_1peak__detector.html#ac6beede9f2e37e021f6dbe73f03bf62d", null ],
      [ "threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector.html#a047328432ad0ef2eebaa4baf9bf63509", null ]
    ] ],
    [ "gr::blocks::peak_detector2_fb", "classgr_1_1blocks_1_1peak__detector2__fb.html", [
      [ "sptr", "classgr_1_1blocks_1_1peak__detector2__fb.html#af65ec5bcbe0cd7c2d6faf1fb80fc3cb5", null ],
      [ "alpha", "classgr_1_1blocks_1_1peak__detector2__fb.html#a7ec2464e915b68edb0a2d3a6a6e98f49", null ],
      [ "look_ahead", "classgr_1_1blocks_1_1peak__detector2__fb.html#a802cb9e115e1660c6829053093e0ea95", null ],
      [ "make", "classgr_1_1blocks_1_1peak__detector2__fb.html#a23da224e47997990fcf7855e7caf2d63", null ],
      [ "set_alpha", "classgr_1_1blocks_1_1peak__detector2__fb.html#a4af0ffb9360d30d4d152fa248c8943c7", null ],
      [ "set_look_ahead", "classgr_1_1blocks_1_1peak__detector2__fb.html#a098634990328c59377d2e955de83c7d0", null ],
      [ "set_threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector2__fb.html#aef0f59adaaccade1af5ae75c383e9d1c", null ],
      [ "threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector2__fb.html#a2d73b8767ca5212f8223e218f315bc6d", null ]
    ] ],
    [ "gr::blocks::plateau_detector_fb", "classgr_1_1blocks_1_1plateau__detector__fb.html", [
      [ "sptr", "classgr_1_1blocks_1_1plateau__detector__fb.html#acf73ed83bce9695ebe910cd334f3398e", null ],
      [ "make", "classgr_1_1blocks_1_1plateau__detector__fb.html#a52504a01aff3f7e11511cb7500e1ca6a", null ],
      [ "set_threshold", "classgr_1_1blocks_1_1plateau__detector__fb.html#a329d6ff3b8f558d72d1715f35603851a", null ],
      [ "threshold", "classgr_1_1blocks_1_1plateau__detector__fb.html#a87108f096231fa68a235386b4dde19cb", null ]
    ] ]
];

==> gnuradio-docs-3.10.12.0-10-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/group__peak__detectors__blk.js <==
var group__peak__detectors__blk =
[
    [ "gr::analog::dpll_bb", "classgr_1_1analog_1_1dpll__bb.html", [
      [ "sptr", "classgr_1_1analog_1_1dpll__bb.html#a4cd3aab598fe459a633a410d9dc5f2bd", null ],
      [ "decision_threshold", "classgr_1_1analog_1_1dpll__bb.html#a53e1c566e50ef63f4d5e0b8fb84a484e", null ],
      [ "freq", "classgr_1_1analog_1_1dpll__bb.html#abedeabbf4b0049752c0b3be852e95a3c", null ],
      [ "gain", "classgr_1_1analog_1_1dpll__bb.html#a1da82673c6f625cd7cf0f444852cd0a4", null ],
      [ "make", "classgr_1_1analog_1_1dpll__bb.html#a980b6ceddb6b3209359bb3aa1f36976e", null ],
      [ "phase", "classgr_1_1analog_1_1dpll__bb.html#aab727744be92198f2d4711e5f0f19678", null ],
      [ "set_decision_threshold", "classgr_1_1analog_1_1dpll__bb.html#a546eabcaa34f18be69565c641601ec3d", null ],
      [ "set_gain", "classgr_1_1analog_1_1dpll__bb.html#a02c324b9cf55007fc47fdb2da3084ee5", null ]
    ] ],
    [ "gr::blocks::burst_tagger", "classgr_1_1blocks_1_1burst__tagger.html", [
      [ "sptr", "classgr_1_1blocks_1_1burst__tagger.html#a1273ae5546bff6510eddff6f95efbce7", null ],
      [ "make", "classgr_1_1blocks_1_1burst__tagger.html#a4908a2d6815e3d9a12b2b7212161dc08", null ],
      [ "set_false_tag", "classgr_1_1blocks_1_1burst__tagger.html#aeab711b3fa1a9cc7faac0f511dd5b63d", null ],
      [ "set_true_tag", "classgr_1_1blocks_1_1burst__tagger.html#ab6b752543e52c9fca97343a1cac39d7c", null ]
    ] ],
    [ "gr::blocks::peak_detector&lt; T &gt;", "classgr_1_1blocks_1_1peak__detector.html", [
      [ "sptr", "classgr_1_1blocks_1_1peak__detector.html#a004eabbc41caff4d11bc4e48b8fc8fd7", null ],
      [ "alpha", "classgr_1_1blocks_1_1peak__detector.html#a84b44dfcbb5afe0f66b9b3f6beeccebc", null ],
      [ "look_ahead", "classgr_1_1blocks_1_1peak__detector.html#ab23b61ab46bc6d7f120e7a6b152ab56d", null ],
      [ "make", "classgr_1_1blocks_1_1peak__detector.html#aab118d4bb43e6884f87fc7f99b18c26c", null ],
      [ "set_alpha", "classgr_1_1blocks_1_1peak__detector.html#aae8136f9c7c7990aaa1217e1b21973be", null ],
      [ "set_look_ahead", "classgr_1_1blocks_1_1peak__detector.html#a6b0179950aef78cfccf0db5e4fb7c8f1", null ],
      [ "set_threshold_factor_fall", "classgr_1_1blocks_1_1peak__detector.html#a78f1f05b1345d3fd248f7112b0b9dfae", null ],
      [ "set_threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector.html#ace2098fbf2075d6c0c0cc2190a071cf2", null ],
      [ "threshold_factor_fall", "classgr_1_1blocks_1_1peak__detector.html#ac6beede9f2e37e021f6dbe73f03bf62d", null ],
      [ "threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector.html#a047328432ad0ef2eebaa4baf9bf63509", null ]
    ] ],
    [ "gr::blocks::peak_detector2_fb", "classgr_1_1blocks_1_1peak__detector2__fb.html", [
      [ "sptr", "classgr_1_1blocks_1_1peak__detector2__fb.html#af65ec5bcbe0cd7c2d6faf1fb80fc3cb5", null ],
      [ "alpha", "classgr_1_1blocks_1_1peak__detector2__fb.html#a7ec2464e915b68edb0a2d3a6a6e98f49", null ],
      [ "look_ahead", "classgr_1_1blocks_1_1peak__detector2__fb.html#a802cb9e115e1660c6829053093e0ea95", null ],
      [ "make", "classgr_1_1blocks_1_1peak__detector2__fb.html#a23da224e47997990fcf7855e7caf2d63", null ],
      [ "set_alpha", "classgr_1_1blocks_1_1peak__detector2__fb.html#a4af0ffb9360d30d4d152fa248c8943c7", null ],
      [ "set_look_ahead", "classgr_1_1blocks_1_1peak__detector2__fb.html#a098634990328c59377d2e955de83c7d0", null ],
      [ "set_threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector2__fb.html#aef0f59adaaccade1af5ae75c383e9d1c", null ],
      [ "threshold_factor_rise", "classgr_1_1blocks_1_1peak__detector2__fb.html#a2d73b8767ca5212f8223e218f315bc6d", null ]
    ] ],
    [ "gr::blocks::plateau_detector_fb", "classgr_1_1blocks_1_1plateau__detector__fb.html", [
      [ "sptr", "classgr_1_1blocks_1_1plateau__detector__fb.html#acf73ed83bce9695ebe910cd334f3398e", null ],
      [ "make", "classgr_1_1blocks_1_1plateau__detector__fb.html#a52504a01aff3f7e11511cb7500e1ca6a", null ],
      [ "set_threshold", "classgr_1_1blocks_1_1plateau__detector__fb.html#a329d6ff3b8f558d72d1715f35603851a", null ],
      [ "threshold", "classgr_1_1blocks_1_1plateau__detector__fb.html#a87108f096231fa68a235386b4dde19cb", null ]
    ] ]
];
